pub enum CrashEventResult {
Handled(bool),
Jump {
jmp_buf: *mut JmpBuf,
value: i32,
},
}
The result of the user code executed during a crash event
The event was handled in some way
Fields
The location to jump back to, retrieved via sig/setjmp
The value that will be returned from the sig/setjmp call that we
jump to. Note that if the value is 0 it will be corrected to 1
The handler wishes to jump somewhere else, presumably to return
execution and skip the code that caused the exception
Converts to this type from the input type.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.