Enum crash_handler::ExceptionCode
source · #[repr(i32)]
pub enum ExceptionCode {
Abort,
Fpe,
Illegal,
Segv,
StackOverflow,
Trap,
InvalidParameter,
Purecall,
User,
}Expand description
Possible exception codes values for the the exception_code field
in the crash context.
This is mainly for testing purposes, and is not exhaustive nor really accurate, as eg. a distinction is made between a divide by zero between integers and floats.
Variants