#[repr(C)]
pub struct JmpBuf { /* private fields */ }
A jump buffer.
This is essentially the register state of a point in execution at the time
of a sigsetjmp call that can be returned to by passing this buffer to
siglongjmp.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.