pub struct CrashHandler;
A Linux/Android signal handler

Implementations

Attaches the signal handler.

The provided callback will be invoked if a signal is caught, providing a crate::CrashContext with the details of the thread where the signal was raised.

The callback runs in a compromised context, so it is highly recommended to not perform actions that may fail due to corrupted state that caused or is a symptom of the original signal. This includes doing heap allocations from the same allocator as the crashing code.

Detaches the handler.

This is done automatically when this CrashHandler is dropped.

Sends the specified user signal.